==> apache-hyracks-0.3.3-source-release.zip: apache-hyracks-0.3.3/hyracks/hyracks-api/src/main/java/org/apache/hyracks/api/job/JobInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.api.job;

import java.io.Serializable;
import java.util.Map;

import org.apache.hyracks.api.dataflow.OperatorDescriptorId;

public class JobInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    private final JobId jobId;

    private final JobStatus status;

    private final Map<OperatorDescriptorId, Map<Integer, String>> operatorLocations;

    public JobInfo(JobId jobId, JobStatus jobStatus, Map<OperatorDescriptorId, Map<Integer, String>> operatorLocations) {
        this.jobId = jobId;
        this.operatorLocations = operatorLocations;
        this.status = jobStatus;
    }

    public JobId getJobId() {
        return jobId;
    }

    public JobStatus getStatus() {
        return status;
    }

    public Map<OperatorDescriptorId, Map<Integer, String>> getOperatorLocations() {
        return operatorLocations;
    }

}

==> apache-hyracks-0.3.8.2-source-release.zip: apache-hyracks-0.3.8.2/hyracks/hyracks-api/src/main/java/org/apache/hyracks/api/job/JobInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.api.job;

import java.io.Serializable;
import java.util.Map;

import org.apache.hyracks.api.dataflow.OperatorDescriptorId;

public class JobInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    private final JobId jobId;

    private final JobStatus status;

    private final Map<OperatorDescriptorId, Map<Integer, String>> operatorLocations;

    public JobInfo(JobId jobId, JobStatus jobStatus,
            Map<OperatorDescriptorId, Map<Integer, String>> operatorLocations) {
        this.jobId = jobId;
        this.operatorLocations = operatorLocations;
        this.status = jobStatus;
    }

    public JobId getJobId() {
        return jobId;
    }

    public JobStatus getStatus() {
        return status;
    }

    public Map<OperatorDescriptorId, Map<Integer, String>> getOperatorLocations() {
        return operatorLocations;
    }

}
